==> haskell-primitive-unaligned-0.1.1.2-113-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-unaligned.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 primitive-unaligned
version:              0.1.1.2
visibility:           public
id:                   primitive-unaligned-0.1.1.2-KuwwEPE5tOQ7WI3hxpqclQ
key:                  primitive-unaligned-0.1.1.2-KuwwEPE5tOQ7WI3hxpqclQ
license:              BSD-3-Clause
copyright:            2019 Andrew Martin
maintainer:           Andrew Martin <andrew.thaddeus@gmail.com>
author:               Andrew Martin
homepage:             https://github.com/haskell-primitive/primitive-unaligned
synopsis:             Unaligned access to primitive arrays
description:
    Unaligned access to primitive arrays. The offsets are given in bytes rather than elements.

category:             Data
abi:                  3f5d7a3c956d9bac3e985b64330ff3e9
exposed:              True
exposed-modules:      Data.Primitive.ByteArray.Unaligned
hidden-modules:       Data.Primitive.Unaligned.Mach
import-dirs:          /usr/lib/ghc-9.4.8/site-local/primitive-unaligned-0.1.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/primitive-unaligned-0.1.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/primitive-unaligned-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-unaligned
hs-libraries:         HSprimitive-unaligned-0.1.1.2-KuwwEPE5tOQ7WI3hxpqclQ
depends:
    base-4.17.2.1 primitive-0.9.1.0-LKIwDdhUWCeBBmo7dhK3va

haddock-interfaces:
    /usr/share/doc/haskell-primitive-unaligned/html/primitive-unaligned.haddock

haddock-html:         /usr/share/doc/haskell-primitive-unaligned/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-primitive-unaligned-0.1.1.2-114-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-unaligned.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 primitive-unaligned
version:              0.1.1.2
visibility:           public
id:                   primitive-unaligned-0.1.1.2-2X2cebbpDsCIwSBFmeAjPP
key:                  primitive-unaligned-0.1.1.2-2X2cebbpDsCIwSBFmeAjPP
license:              BSD-3-Clause
copyright:            2019 Andrew Martin
maintainer:           Andrew Martin <andrew.thaddeus@gmail.com>
author:               Andrew Martin
homepage:             https://github.com/haskell-primitive/primitive-unaligned
synopsis:             Unaligned access to primitive arrays
description:
    Unaligned access to primitive arrays. The offsets are given in bytes rather than elements.

category:             Data
abi:                  697938aa68090a1bfdbdb719f94964f1
exposed:              True
exposed-modules:      Data.Primitive.ByteArray.Unaligned
hidden-modules:       Data.Primitive.Unaligned.Mach
import-dirs:          /usr/lib/ghc-9.4.8/site-local/primitive-unaligned-0.1.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/primitive-unaligned-0.1.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/primitive-unaligned-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-unaligned
hs-libraries:         HSprimitive-unaligned-0.1.1.2-2X2cebbpDsCIwSBFmeAjPP
depends:
    base-4.17.2.1 primitive-0.9.1.0-8nzcMUtKW4yAfvV7oeRfvP

haddock-interfaces:
    /usr/share/doc/haskell-primitive-unaligned/html/primitive-unaligned.haddock

haddock-html:         /usr/share/doc/haskell-primitive-unaligned/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
